@@ -21,6 +21,7 @@ const (
 	// FetchVirtualEnv fetches the virtual env
 	FetchVirtualEnv      properties.Property = "fetch_virtual_env"
 	UsePythonVersionFile properties.Property = "use_python_version_file"
+	FolderNameFallback   properties.Property = "folder_name_fallback"
 )
 
 func (p *Python) Template() string {
@@ -74,6 +75,7 @@ func (p *Python) loadContext() {
 		"CONDA_DEFAULT_ENV",
 	}
 
+	folderNameFallback := p.language.props.GetBool(FolderNameFallback, true)
 	defaultVenvNames := []string{
 		".venv",
 		"venv",
@@ -87,8 +89,7 @@ func (p *Python) loadContext() {
 		}
 
 		name := platform.Base(p.language.env, venv)
-
-		if slices.Contains(defaultVenvNames, name) {
+		if folderNameFallback && slices.Contains(defaultVenvNames, name) {
 			venv = strings.TrimSuffix(venv, name)
 			name = platform.Base(p.language.env, venv)
 		}
